s6: the s6-fdholder-list program
Keywords: s6 s6-fdholder fd-holding fd-holder fd list unix socket activation

s6
Software
skarnet.org

# The `s6-fdholder-list` program

`s6-fdholder-list` lists the descriptors currently held by a fd-holding daemon.

## Interface

         s6-fdholder-list [ -t timeout ] path

- s6-fdholder-list executes into `s6-ipcclient path s6-fdholder-listc id`. It does nothing else: it is just a convenience program. The s6-ipcclient program connects to a Unix socket at path, and the s6-fdholder-listc program transmits the instruction over the socket, and gets and prints the result.

## Options

- `-t timeout` : if the operation cannot be processed in timeout milliseconds, then fail with an error message. Communications with the server should be near-instant, so this option is only here to protect users against programming errors (connecting to the wrong socket, for instance).